#
# spec file for package buildpacks-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

%define executable_name pack
%define repo_name pack

Name:           buildpacks-cli
Version:        0.35.0
Release:        1.1
Summary:        CLI for building apps using Cloud Native Buildpacks
License:        Apache-2.0
URL:            https://github.com/buildpacks/pack
Source:         %{repo_name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22
Provides:       pack = %{version}
Conflicts:      allegro44-tools

%description
pack makes it easy for...

* App Developers to use buildpacks to convert code into runnable images.
* Buildpack Authors to develop and package buildpacks for distribution.
* Operators to package buildpacks for distribution and maintain applications.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1 -n %{repo_name}-%{version}

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/buildpacks/pack.Version=%{version}" \
   -o bin/%{executable_name} ./cmd/%{executable_name}

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{executable_name}

%changelog
* Mon Jul 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.35.0:
  * Log a warning (once) when PACK_VOLUME_KEY is unset and running in a container
  * Validate build image name
  * Try to fix wcow
  * Fix macos by not requiring real docker client for lifecycle execution unit tests
  * Launch build containers in a separate ephemeral Docker bridge network
  * Resolve some TODOs
  * Initial implementation (still has TODOs)
  * Warn if NOT --pull-policy=always in container
* Mon Jul 22 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package buildpacks-cli: CLI for building apps using Cloud
  Native Buildpacks
